<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 04, 2021
 */

/**
 * @package InterWorx
 * @subpackage CLI
 */
class AcronisDbInfo extends CLI
{
    const FUNCTION_GENERATE = 'generateJsonSw';
    const UNIQNAME = 'uniqname';

    const JSON_FILE_SW = 'dbinfosw.json';
    const JSON_FILE_LOCATION_SW = Model_Recovery_Files_Databases::DUMPS_TEMP_PATH . "/" . self::JSON_FILE_SW;

    const DATABASES = 'databases';
    const NAME = 'name';
    const SIZE = 'size';
    const HOST = 'host';
    const UNIXUSER = 'unixuser';
    const UNIT = 'unit';
    const PATH = 'dumps_path';

    /**
     * Register functions, install & uninstall.
     */
    public function registerOptArgs()
    {
        $this->_func(self::FUNCTION_GENERATE, 'cache backup info');
    }

    /**
     * Generate json file with db info
     * for SW users
     */
    protected function _generateJsonSw()
    {
        $users = $this->_getUnixUsers();
        $content = array();

        foreach ($users as $user) {
            $content = array_merge($this->_getDbsInfo($user), $content);
        }

        Model_AcronisFileSys::createDir(Model_Recovery_Files_Databases::DUMPS_TEMP_PATH);
        IWorx_Json::writeToFile($content, self::JSON_FILE_LOCATION_SW);
    }

    /**
     * @param string $unixuser
     */
    private function _getDbsInfo($unixuser)
    {
        $SW = new SiteWorx();
        $SW->populateUniqname($unixuser);
        $Driver = $SW->getMySQLDriver();

        $dbs = array();
        foreach ($Driver->getDatabases() as $db) {
            $sizeInBytes = $Driver->getDatabaseStorageBytes($db->fqdn);
            $dbs[] = $this->_formatDbInfo($db, $unixuser, $sizeInBytes);
        }

        return $dbs;
    }

    /**
     * @param object  $dbInfo
     * @param string  $unixuser
     * @param integer $sizeInBytes
     */
    private function _formatDbInfo($dbInfo, $unixuser, $sizeInBytes)
    {
        $name = $dbInfo->fqdn;
        $host = $dbInfo->host;
        $path = Model_AcronisFileSys::getDatabaseDumpsPath($unixuser, $name);

        return array(
            self::NAME => $name,
            self::SIZE => $sizeInBytes,
            self::UNIT => 'B',
            self::HOST => $host,
            self::UNIXUSER => $unixuser,
            self::PATH => $path
        );
    }

    /**
     *
     * @return array
     */
    private function _getUnixUsers()
    {
        $NW = new NodeWorx(NodeWorx::MASTER_ID);
        $Search = new IWorx_Search_SiteworxAccounts($NW);
        $Search->addSelectableFields('uniqname');

        $format = IWorx_Search_SiteworxAccounts::FETCH_ASSOC;
        $users = $Search->search($format);

        return array_map(function ($user) {
            return $user[self::UNIQNAME];
        }, $users);
    }
}
