<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Dec 07, 2020
 */

/**
 * @package InterWorx
 * @subpackage Plugin
 */
class Form_AbActivatePlan extends Form
{
    const INPUT_PLAN_ID = 'plan_id';
    const FORM_NAME = 'ab_activate_plan';

    /**
     * Initialize.
     */
    protected function _initialize()
    {
        parent::_initialize(self::FORM_NAME);
        $ds_plan_ids = $this->_getPlanIds();

        $this->addInput(new Input_Select(self::INPUT_PLAN_ID))
            ->setDataSource(new DataSource_Array($ds_plan_ids))
            ->setHidden(true)
            ->setRequired(false);
    }

    /**
     * Get plan ids.
     *
     * @return array
     */
    private function _getPlanIds()
    {
        $BackupPlan = new Model_Backups_BackupPlan();
        $Policies = $BackupPlan->getApplicablePolicies();

        return array_map(function ($Policy) {
            return $Policy->getId();
        }, $Policies);
    }

    /**
     * Check if there is a backup plan applied to this resource
     *
     * @return boolean
     */
    private function _isBackupPlanApplied()
    {
        try {
            $BackupPlan = new Model_Backups_BackupPlan();
            $BackupPlan->getAppliedPolicy();
            return true;
        } catch (Exception_Acronis_BackupPlan_NoneAssigned $e) {
            return false;
        }
    }

    /**
     *
     * @return boolean
     * @throws IWorx_Exception_Input
     */
    protected function _validate()
    {
        if ($this->_isBackupPlanApplied()) {
            if ($this->getValue(self::INPUT_PLAN_ID) == null) {
                $this->addError("A backup plan is already applied. You must provide 'plan_id' to activate another.");
                return false;
            }
        }
        return true;
    }
}
