<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Dec 22, 2020
 */

/**
 * @package InterWorx
 * @subpackage Plugin
 */
class Model_ApiResponse_Task
{
    const API_RESULT = 'result';
    const API_CODE = 'code';
    const API_CODE_ERROR = 'error';
    const API_CODE_OK = 'ok';
    const API_DEBUG = 'debug';
    const API_DEBUG_MESSAGE = 'msg';
    const API_PROGRESS = 'progress';
    const API_ID = 'id';
    const API_UUID = 'uuid';
    const API_STATE = 'state';
    const API_CONTEXT = 'context';
    const API_POLICY = 'policy';
    const API_TYPE = 'type';

    private $_progress;
    private $_id;
    private $_uuid;
    private $_state;
    private $_code_type;
    private $_code_error;
    private $_error_message;
    private $_error_details;
    private $_policy_id;
    private $_policy_type;

    /**
     * @param array $response
     */
    public function __construct(array $response)
    {
        $result = $response[self::API_RESULT];

        $this->_progress = $response[self::API_PROGRESS];
        $this->_id = $response[self::API_ID];
        $this->_uuid = $response[self::API_UUID];
        $this->_state = $response[self::API_STATE];
        $this->_code_type = $result[self::API_CODE];
        $this->_policy_type = $response[self::API_POLICY][self::API_TYPE];
        $this->_policy_id = $response[self::API_POLICY][self::API_ID];

        if ($this->_recoveryErrorDetected()) {
            $error = $result[self::API_CODE_ERROR];

            $this->_code_error = $error[self::API_CODE];
            $this->_error_details = $error[self::API_CONTEXT];
            $this->_error_message = $error[self::API_DEBUG][self::API_DEBUG_MESSAGE];
        }
    }

    /**
     * @return boolean
     */
    private function _recoveryErrorDetected()
    {
        return $this->_code_type === self::API_CODE_ERROR;
    }

    /**
     * @return boolean
     */
    public function getCodeType()
    {
        return $this->_code_type;
    }

    /**
     * @return boolean
     */
    public function getCodeError()
    {
        return $this->_code_error;
    }

    /**
     * @return boolean
     */
    public function errorDetected()
    {
        return $this->_recoveryErrorDetected();
    }

    /**
     * @return string
     */
    public function getErrorMessage()
    {
        return $this->_error_message;
    }

    /**
     * @return string
     */
    public function getErrorDetails()
    {
        return $this->_error_details;
    }

    /**
     * @return string
     */
    public function getId()
    {
        return $this->_id;
    }

    /**
     * @return string
     */
    public function getUuid()
    {
        return $this->_uuid;
    }

    /**
     * @return string
     */
    public function getProgressPercent()
    {
        $percentage = $this->_progress['current'];
        return "$percentage%";
    }

    /**
     * @return string
     */
    public function getState()
    {
        return $this->_state;
    }

    /**
     * @return array
     */
    public function getRawResponse()
    {
        return $this->_res;
    }

    /**
     * Get policy id
     */
    public function getPolicyId()
    {
        return $this->_policy_id;
    }

    /**
     * Get policy type (backup/restore)
     */
    public function getPolicyType()
    {
        return $this->_policy_type;
    }
}
