<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 12, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_List_Nodeworx extends Model_Backups_List
{
    /**
     * Update backups. Ensures that we have the
     * latest backups in cache.
     */
    public function updateBackups()
    {
        $this->_cacheBackupsFromApi();
    }

    /**
     * Get backups.
     *
     * @return array
     */
    public function getBackups()
    {
        $this->_updateBackups();
        $backups = $this->_getBackupsSortedByDate();
        return $backups;
    }

    /**
     * Delete all prescript data that has not been mapped
     * to a backup.
     */
    public function deleteUnmappedPrescripts()
    {
        $PrescriptCache = $this->_getPrescriptCache();
        $PrescriptCache->deleteAll();
    }

    /**
     * Get prescript data not mapped to any backup.
     *
     * @return array
     */
    public function getUnmappedPrescriptData()
    {
        $PrescriptCache = $this->_getPrescriptCache();
        return $PrescriptCache->getAll();
    }

    /**
     * Regenerate prescript data in backup cache
     * for all backups lacking this information.
     */
    public function regenerateMissingPrescriptCache()
    {
        $Backups = $this->_getBackupsWithoutPrescriptInfo();

        foreach ($Backups as $Backup) {
            $this->_tryRefreshBackupCache($Backup);
        }
    }

    /**
     * @param Model_Backups_Backup $Backup
     */
    private function _tryRefreshBackupCache(Model_Backups_Backup $Backup)
    {
        try {
            $Backup->refreshCache();
        } catch (Exception_Acronis $E) {
            // if refresh fails due to missing
            // backup files, we will log and move on
            IW::getLog()->info($E->getMessage());
        }
    }
}
