<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jan 12, 2021
 */

use Monolog\Logger;
use Monolog\Handler\StreamHandler;
use Monolog\Handler\FirePHPHandler;

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Logger_Api
{
    const LOG_DIR = '/home/interworx/var/log/acronis/api.log';

    private $_Logger;

    /**
     * Set logger.
     */
    public function __construct()
    {
        $Logger = new Logger('api');
        $Logger->pushHandler(new StreamHandler(self::LOG_DIR), $Logger::INFO);
        $Logger->pushHandler(new FirePHPHandler());

        $this->_Logger = $Logger;
    }

    /**
     * Log api request.
     *
     * @param string  $requestUrl
     * @param integer $responseCode
     * @param string  $requestMethod
     * @param mixed   $requestData
     */
    public function logApiRequest($requestUrl, $responseCode, $requestMethod, $requestData = null)
    {
        $request = array(
            'requestUrl' => $requestUrl,
            'requestMethod' => $requestMethod,
            'responseCode' => $responseCode,
            'requestData' => $requestData
        );

        $this->_Logger->info('apiRequest', $request);
    }
}
