<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Sep 03, 2021
 */

require_once(__DIR__ . '/../../Nodeworx.php');

/**
 * Note: This test depends on RunBackup.php runBackupTest.
 * Run test suite in plugin test folder to include
 *
 * @package InterWorx
 * @subpackage
 */
class NwRecoverDirectoriesAltLocationTest extends Acronis_NodeworxTest
{

    /**
     * Delete temp restore dir if exists.
     */
    public function setUp()
    {
        $this->_deleteTempDirIfExists();
    }

    /**
     * Delete temp restore dir if exists.
     */
    public function tearDown()
    {
        $this->_deleteFlagInitiatedIfExists();
        $this->_deleteTempDirIfExists();
    }

    /**
     * Test recover directories. New dirs should not be deleted.
     */
    public function testRecoverDirectoriesAltLocation()
    {
        echo __FUNCTION__;
        $this->_awaitRestores();

        $Reply = $this->_recoverDirectoriesAltLocation();
        $this->assertReplySuccessful($Reply);

        $payloadData = $Reply->getPayloadData();
        $planId = $payloadData['planId'];

        $this->_awaitRestore($planId);
        $this->_assertFilesRestoredToTemp();

        return $planId;
    }

    /**
     * make sure files recovered to temp location
     */
    private function _assertFilesRestoredToTemp()
    {
        $pathRestoredFolder = $this->_getRestoredPath(Model_Recovery_Files::NW_DOWNLOAD_DIR_PATH);
        $this->assertTrue(Model_AcronisFileSys::isDir($pathRestoredFolder));

        // make sure restored content properly
        $content = Model_AcronisFileSys::getDirContent($pathRestoredFolder);
        $this->assertCount(400, $content);
    }

    /**
     * @depends testRecoverDirectoriesAltLocation
     * @param string $planId
     */
    public function testListRecoveries($planId)
    {
        echo __FUNCTION__;

        $Reply = $this->_sendCtrlRequest('listRecoveries');
        $this->assertReplySuccessful($Reply);

        // assume latest restore is first item
        $payloadData = $Reply->getPayloadData();
        $restore = $payloadData[0];
        $this->assertSame(strtoupper($planId), strtoupper($restore['planId']));
    }


    /**
     * test recoverDirectories should fail when flag "initiated" is set
     */
    public function testRecoverDirectoriesAltLocationShouldFailWhileInitiated()
    {
        echo __FUNCTION__;

        $this->_setInitiated();

        $Reply = $this->_recoverDirectoriesAltLocation();
        $this->assertReplyNotSuccessful($Reply, 'expected action to fail while initiated flag is set');
        $this->_assertReplyReturnsRestoreInProgress($Reply);

        $this->_clearInitiated();
    }

    /**
     * @return Reply
     */
    private function _recoverDirectoriesAltLocation()
    {
        $dirs =  array(self::PARENT_DIR_PATH_TEST);
        $Backup = $this->_getBackup();

        $args = array(
            Form_AcronisBackups::INPUT_MULTI_DIR => $dirs,
            Form_AcronisBackups::INPUT_BACKUP_ID => $Backup->getBackupId()
        );

        return $this->_sendCtrlRequest('restoreToAltLocation', $args);
    }
}
