<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 23, 2021
 */

 require_once(__DIR__ . '/AcronisTestCase.php');
/**
 * @package InterWorx
 * @subpackage
 */
abstract class Acronis_SiteworxTest extends AcronisTestCase
{
    const SW_ACRONIS_NEWACCT = 'newacct';

    /**
     * @param string $action
     * @param array  $args
     * @param string $user
     * @return Reply
     */
    protected function _sendCtrlRequest($action, array $args = array(), $user = self::ACRONISTESTUSER)
    {
        return $this->_sendSwCtrlRequest($action, $args, $user);
    }

    /**
     * Create sw account
     *
     * @param string $name
     */
    protected function _createSwAccount($name = self::ACRONISTESTUSER)
    {
        $this->_validateSwAccountDoesNotExist($name);

        $phpbin = "/home/interworx/bin/php";
        $script = "/home/interworx/plugins/acronis/bin/acronisdbseeder.php";
        $cmd = "$phpbin $script --createSw --username=$name";
        Model_AcronisUtil::exec($cmd);
    }

    /**
     * @param string $name
     */
    protected function _deleteSwAccount($name)
    {
        $this->_validateSwAccountExist($name);

        $phpbin = "/home/interworx/bin/php";
        $script = "/home/interworx/plugins/acronis/bin/acronisdbseeder.php";
        $cmd = "$phpbin $script --deleteSw --username=$name";
        Model_AcronisUtil::exec($cmd);
    }

    /**
     * @param string $name
     */
    private function _validateSwAccountDoesNotExist($name)
    {
        $SW = new SiteWorx();
        $SW->populateUniqname($name);
        if ($SW->exists()) {
            $this->fail('Siteworx account already exists: ' . $name);
        }
    }

    /**
     * @param string $name
     */
    private function _validateSwAccountExist($name)
    {
        $SW = new SiteWorx();
        $SW->populateUniqname($name);
        if (!$SW->exists()) {
            $this->fail('Siteworx account does not exists: ' . $name);
        }
    }

    /**
     * @param string $user
     * @return array
     */
    protected function _getSwBackups($user)
    {
        $Reply = $this->_sendCtrlRequest('listBackups', array(), $user);
        return $Reply->getPayloadData();
    }

    /**
     * @param string $user
     * @return Model_Backups_Backup
     */
    protected function _getLatestSwBackup($user)
    {
        $swBackups = $this->_getSwBackups($user);
        $latestBackup = $swBackups[0];
        return new Model_Backups_Backup($latestBackup);
    }

    /**
     * @param string $user
     * @param string $relativePath
     */
    protected function _getSwAbsolutePath($user, $relativePath)
    {
        $path = ltrim($relativePath, '/');
        return "/home/$user/$path";
    }
}
