<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Sep 20, 2021
 */
require_once(__DIR__ . '/../../Siteworx.php');
/**
 * @package InterWorx
 * @subpackage
 */
class SwGetDefaultRestoreLocationTest extends Acronis_SiteworxTest
{
    const NEW_USER = 'newusessr';

    /**
     * delete test user after tests.
     */
    public function tearDown()
    {
        $SW = $this->_getSw(self::NEW_USER);
        if ($SW->exists()) {
            $this->_deleteSwAccount(self::NEW_USER);
        }
    }
    /**
     * test getDefaultRestoreLocation for sw account acronistest
     */
    public function testGetDefaultRestoreLocationAcronistest()
    {
        echo __FUNCTION__;

        $expected = "/home/acronistest/acronis_temp";

        $Reply = $this->_sendCtrlRequest('getDefaultRestoreLocation');
        $actual = $Reply->getPayloadData()['location'];

        $this->assertSame($expected, $actual);
    }


    /**
     * test getDefaultRestoreLocation for sw account acronistest
     */
    public function testGetDefaultRestoreLocationNewuser()
    {
        echo __FUNCTION__;

        $newuser = 'newuser';

        $SW = $this->_getSw($newuser);
        if (!$SW->exists()) {
            $this->_createSwAccount($newuser);
        }

        $expected = "/home/$newuser/acronis_temp";

        $Reply = $this->_sendCtrlRequest('getDefaultRestoreLocation', array(), $newuser);
        $actual = $Reply->getPayloadData()['location'];

        $this->assertSame($expected, $actual);
    }
}
